@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0+   2011/02/14
+ * Version: 1.8.3   2011/09/29
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -579,7 +579,8 @@ int main(int argc, char *argv[])
 		else
 			printf("FAILED: %s\n", strerror(errno));
 
-		fprintf(domain_fp, "delete file pivot_root proc:/ proc:/ccs/\n");
+		fprintf(domain_fp,
+			"delete file pivot_root proc:/ proc:/ccs/\n");
 		snprintf(stack, 8191, "pivot_root('proc:/', 'proc:/ccs/')");
 		show_prompt(stack, 1);
 		{
